// Подключаем библиотеку для работы с esp8266
#include <ESP8266WiFi.h> 
// Подключаем библиотеку DHT для работы с DHT11 
#include <DHT.h> 
// пин подключения контакта DATA (GPIO5)
#define DHTPIN 5
// датчик DHT11
#define DHTTYPE DHT11

// создание экземпляра объекта DHT
DHT dht(DHTPIN, DHTTYPE);

// Подключаем библиотеки для работы с дисплеем Nokia5110 
#include <SPI.h>
#include <Adafruit_GFX.h>
#include <Adafruit_PCD8544.h>
// ESP8266 Software SPI (slower updates, more flexible pin options):
// pin 14 - Serial clock out (SCLK)
// pin 13 - Serial data out (DIN)
// pin 12 - Data/Command select (D/C)
// pin 15 - LCD chip select (CS)
// pin 4 - LCD reset (RST)
// создание экземпляра объекта Adafruit_PCD8544
Adafruit_PCD8544 display = Adafruit_PCD8544(14, 13, 12, 15, 4);

// ssid WiFi сети подключения
const char* ssid = "**********"; 
// Пароль  WiFi сети подключения 
const char* password = "********"; 
// Сервер ThingSpeak
const char* host = "184.106.153.149"; 
// API KEY вашего приложения ThingSpeak
const char* privateKey = "****************"; 
// переменные для хранения температуры и влажности
float temp; 
float humidity; 
// переменная для интервала измерений
unsigned long millis_int1=0;
unsigned long interval=10000;

void setup() {
  // запуск последовательного порта 
  Serial.begin(115200); 
  delay(10);
  Serial.print("Connect to WiFi"); 
  Serial.println(ssid);
  display.begin();
  display.setContrast(70);
  display.clearDisplay();
  display.setTextSize(1);
  display.setTextColor(BLACK);
  display.setCursor(0,0);
  display.println("Connect to WiFi");
  display.display();
  // Соединяемся по WiFi
  WiFi.begin(ssid, password);
  
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
  }
  Serial.println("WiFi connected"); 
  // дисплей
  display.begin();
  display.setContrast(70);
  display.clearDisplay();
  display.setTextSize(1);
  display.setTextColor(BLACK);
  display.setCursor(0,0);
  display.println("ESP07 - DHT11");
  display.println("Makerplus.ru");
  display.display();

  display.display(); // show splashscreen
  // запуск dht
  dht.begin(); 
  delay(10000);

}


void loop() {
// ждем интервал 10 минут
if(millis()-millis_int1>=interval) {
  Serial.print("connect to ThingSpeak");
  Serial.println(host);
  
  // Используем WiFi клиент 
  WiFiClient client;
if (!client.connect(host, 80)) {
    Serial.println("connection failed");    
    return;
  }
  // получить данные температуры
  temp = dht.readTemperature();
  humidity = dht.readHumidity();
  // вывод на дисплей
  display.clearDisplay();
  display.setCursor(0,0);
  display.println("ESP07 - DHT11");
  display.println("Makerplus.ru");
  display.print("T=");
  display.print(temp);
  display.println(" *C");
  display.print("H=");
  display.print(humidity);
  display.println(" %");
  display.display(); 
  // Создаем URL с запросом для сервера
  String url = "/update?key=";
  url += privateKey;
  url += "&temp="; 
  url += temp;
  url += "&humidity="; 
  url += humidity;

  // Отправляем запрос на сервер
  client.print(String("GET ") + url + " HTTP/1.1\r\n" + "Host: " + host + "\r\n" + "Connection: close\r\n\r\n");
  delay(10);
  
  // ответ сервера ThingSpeak
  while(client.available()){
    String req = client.readStringUntil('\r');
    Serial.print(req);
  }
  interval=10*60000;
 }
}

